==> haskell-storablevector-0.2.12.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storablevector
version: 0.2.12.1
id: storablevector-0.2.12.1-1COSZ3v5OhZ1D4rcgvpJxz
key: storablevector-0.2.12.1-1COSZ3v5OhZ1D4rcgvpJxz
license: BSD3
maintainer: Henning Thielemann <storablevector@henning-thielemann.de>
stability: Experimental
homepage: http://www.haskell.org/haskellwiki/Storable_Vector
synopsis: Fast, packed, strict storable arrays with a list interface like ByteString
description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.
    .
    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.
category: Data
author: Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict
hidden-modules: Data.StorableVector.Memory
                Data.StorableVector.ST.Private
                Data.StorableVector.Lazy.PointerPrivate
                Data.StorableVector.Lazy.PointerPrivateIndex
                Data.StorableVector.Cursor
abi: 2f31dfe9c01b3aae4d7123ef4bdc51d5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/storablevector-0.2.12.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/storablevector-0.2.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/storablevector-0.2.12.1
hs-libraries: HSstorablevector-0.2.12.1-1COSZ3v5OhZ1D4rcgvpJxz
depends:
    non-negative-0.1.1.2-978XXC1oNssEJaybMovel8
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq transformers-0.5.2.0
    deepseq-1.4.3.0 unsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l base-4.10.1.0
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: non-negative-0.1.1.2-978XXC1oNssEJaybMovel8=e44653168eddd6090df50c770155ba10
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             unsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR=7df145c64396018dcd2e7fe561a83a4f
             QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=a871331a7e5e7b5c37818b7997512ddd
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
haddock-interfaces: /usr/share/doc/haskell-storablevector/html/storablevector.haddock
haddock-html: /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storablevector-0.2.12.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storablevector
version: 0.2.12.1
id: storablevector-0.2.12.1-IT1ntwrrN1jGenS2hzRra0
key: storablevector-0.2.12.1-IT1ntwrrN1jGenS2hzRra0
license: BSD3
maintainer: Henning Thielemann <storablevector@henning-thielemann.de>
stability: Experimental
homepage: http://www.haskell.org/haskellwiki/Storable_Vector
synopsis: Fast, packed, strict storable arrays with a list interface like ByteString
description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.
    .
    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.
category: Data
author: Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict
hidden-modules: Data.StorableVector.Memory
                Data.StorableVector.ST.Private
                Data.StorableVector.Lazy.PointerPrivate
                Data.StorableVector.Lazy.PointerPrivateIndex
                Data.StorableVector.Cursor
abi: 9060a0df19d20683a1ed72a4950691d6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/storablevector-0.2.12.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/storablevector-0.2.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/storablevector-0.2.12.1
hs-libraries: HSstorablevector-0.2.12.1-IT1ntwrrN1jGenS2hzRra0
depends:
    non-negative-0.1.1.2-KGx4UZT49l6H0Y0D8s8xRu
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq transformers-0.5.2.0
    deepseq-1.4.3.0 unsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: non-negative-0.1.1.2-KGx4UZT49l6H0Y0D8s8xRu=674e458999f460d07b55c5fb3d8e590b
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             unsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR=7df145c64396018dcd2e7fe561a83a4f
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
haddock-interfaces: /usr/share/doc/haskell-storablevector/html/storablevector.haddock
haddock-html: /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
